function [] = Dynamics()
% Dynamics.m
%
% kinematics and dynamics
%
% Revision history
% 250507 Drafted
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
global t_in x_in u_cmd dxdt
global N_q N_omg N_h_B N_bttry
global N_Fsrp_B N_pwr
global x_
global angle_tol s_I g_I g
global n_B S0 A cnv_eff
global Pwr_sc Pwr_whl0 Pwr_whl1 Pwr_thr0 Pwr_thr1
global I_B n_B r_B thr_max thr_arm Isp

%%% constants

%%% state variables
q		= x_in(N_q);
omg		= x_in(N_omg);
h_B		= x_in(N_h_B);
bttry	= x_in(N_bttry);

%%% user command (limit is considered)
th_torque	= u_cmd(1:3);
wh_torque	= u_cmd(4:6);

%%% dynamics
L_B		= I_B*omg+h_B;					%% total angular momentum of s/c
u_B		= wh_torque;

C_I2B	= q2DCM(q);
s_B		= C_I2B*s_I;					%% sun direction expressed in body frame
g_B		= C_I2B*g_I;					%% goal direction expressed in body frame
F_B		= SRP_force(n_B,s_B);			%% SRP force expressed in body frame
tau_B	= th_torque + cross(r_B,F_B);	%% thruster torque + SRP torque

%%% generated power
if ( n_B'*s_B > 0 ),
	pwr_gnrt	= S0*A*cnv_eff*(n_B'*s_B);
else
	pwr_gnrt	= 0;
end

%%% consumed power
Pwr_whl		= Pwr_whl0 * 3;
for j = 1:3,
	Pwr_whl		= Pwr_whl + Pwr_whl1*abs(wh_torque(j));
end
Pwr_thr		= Pwr_thr0 * 6;
for j = 1:3,
	Pwr_thr		= Pwr_thr + Pwr_thr1*abs(th_torque(j));
end

pwr_cnsm	= Pwr_sc + Pwr_whl + Pwr_thr;

%%% computation of derivatives
dq		= omg2dq_q(q,omg);
domg	= -inv(I_B)*(cross(omg,I_B*omg+h_B) - u_B - tau_B);
dh_B	= - u_B;

pwr		= pwr_gnrt - pwr_cnsm;	%% generated power - consumed power

dfuel	= -sum(abs(th_torque))/thr_arm/(g*Isp)*2;
if ( n_B'*g_B >= cos(angle_tol) ),
	dpointing	= 1;
else
	dpointing	= 0;
end

dxdt	= [dq;domg;dh_B;pwr;dfuel;dpointing];
x_(N_Fsrp_B)	= F_B;
