function F = SRP_force(n,s)
global d0 d S0 c A rho_s rho_d rho_a Bf
%
% Solar_Radiation_Pressure.m
%
%% Solar Radiation Pressure; SRP
%% Input
%% n	: normal vector of the surface (unit vector) 
%% s	: sun direction vector (unit vector)
%% Output
%% F	: SRP force [N] (3x1 vector)
%% Note. n and s and F are expressed in the same coordinate frame.
%% -----------------------------------
%% d0	:mean distance between the sun and the earth
%% d	:current distance between the sun and the spacecraft
%% S0	:[W/m2]=[J/m2s]=[kg/s3]
%% c	:[m/s] speed of light
%% A	:[m2] area of the plane
%% rho_s:the specular constant
%% rho_d:the diffusion constant
%% rho_a:the absorption constant
%% Bf	:Lambertian constant

F		= - (d0/d)^2*(S0*A/c)*(n'*s)*((2*rho_s*(n'*s)+Bf*rho_d)*n + (rho_d+rho_a)*s);

