function [vertices, faces] = calcBlock(r, R, Lx, Ly, Lz)
% calcBlock.m
%
% Return vertices and faces of a block geometry
% Input
% r 		: position of the center of block (3x1)
% R 		: rotation matrix (3x3)
% Lx,Ly,Lz	: length of the edges along x,y,z axis of the block
% Output
% vertices	: position of the vertices (6x3)
% faces 	: a table of the vertex numbers that make up each face of the block  (6x4)
% 
% Note. vertices are expressed in the body fixed frame.
%
% Ref. https://www.sky-engin.jp/MATLABAnimation/chap09/chap09.html
%
% Revision history
% 250507 Drafted
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

vertices_0 = [
    0,   0,  0;  % #1
    Lx,  0,  0;  % #2
    0,  Ly,  0;  % #3
    0,   0, Lz;  % #4
    Lx, Ly,  0;  % #5
    0,  Ly, Lz;  % #6
    Lx,  0, Lz;  % #7
    Lx, Ly, Lz]; % #8

vertices_0 = vertices_0 - ones(size(vertices_0,1),1)*[Lx/2,Ly/2,Lz/2];
vertices = ones(size(vertices_0,1),1)*r' + vertices_0*R';

faces = [
    1, 2, 5, 3;  % #1
    1, 3, 6, 4;  % #2
    1, 4, 7, 2;  % #3
    4, 6, 8, 7;  % #4
    2, 7, 8, 5;  % #5
    3, 5, 8, 6]; % #6

