function u_cmd = check_command(t_in,x_in,u_user)
%
% check_command.m
%
% Input
%	t_in: current time [s] (1x1)
% 	x_in: state variables
% 	u_user: thruster torque (x,y,z) [Nm] and wheel torque (y,z) [Nm] 
%			(commanded by the user) (5x1 vector)
% Output
% 	u_cmd: thruster torque [Nm] and wheel torque [Nm] 
%			(really applied) (6x1 vector)
%
% Revision history
% 20250507 Drafted
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
global N_h_B N_fuel dth_

global user

hw_max_y	= user.hw_max_y;
hw_max_z	= user.hw_max_z;
trq_max	= user.trq_max;
thr_max	= user.thr_max;
thr_arm	= user.thr_arm;
Isp		= user.Isp;
g		= user.g;
h_B		= x_in(N_h_B);
fuel	= x_in(N_fuel);
%% there is no wheel along x-axis
u_cmd	= [u_user(1:3);[0;u_user(4);u_user(5)]];

%% limit the applied thruster torque
for j = 1:3,
	if ( u_cmd(j) > thr_max*thr_arm ),
		u_cmd(j)	= thr_max*thr_arm;
	end
	if ( u_cmd(j) < -thr_max*thr_arm ),
		u_cmd(j)	= -thr_max*thr_arm;
	end
end
%% limit the applied wheel torque
for j = 5:6,
	if ( u_cmd(j) > trq_max ),
		u_cmd(j)	= trq_max;
	end
	if ( u_cmd(j) < -trq_max ),
		u_cmd(j)	= -trq_max;
	end
end
%% check maximum storable momentum
j	= 2;
if ( h_B(j)-u_cmd(j+3)*dth_>hw_max_y ),
	u_cmd(j+3)	= ( h_B(j)-hw_max_y)/dth_;
elseif ( h_B(j)-u_cmd(j+3)*dth_<-hw_max_y ),
	u_cmd(j+3)	= ( h_B(j)+hw_max_y)/dth_;
end
j	= 3;
if ( h_B(j)-u_cmd(j+3)*dth_>hw_max_z ),
	u_cmd(j+3)	= ( h_B(j)-hw_max_z)/dth_;
elseif ( h_B(j)-u_cmd(j+3)*dth_<-hw_max_z ),
	u_cmd(j+3)	= ( h_B(j)+hw_max_z)/dth_;
end
