function [] = exe_RefreshScreen()
% exe_RefreshScreen.m
%
% Refresh Screen
%
% Revision history
% 250507 Drafted
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
global x_ t_ smt_
global N_q N_omg N_h_B N_bttry N_fuel N_pointing N_u_cmd N_Fsrp_B
global bttry_full initial_fuel
global thr_arm A s_I g_I r_B
global Pix_SS figure_pos
global faces_B vertices_B faces_S vertices_S faces_w vertices_wy vertices_wz axes_body_L
global faces_Thr vertices_Thr

%%% state variables
q		= x_(N_q);
omg		= x_(N_omg);
h_B		= x_(N_h_B);
bttry	= x_(N_bttry);
u_cmd	= x_(N_u_cmd);
Fsrp_B	= x_(N_Fsrp_B);
th_torque	= u_cmd(1:3);
wh_torque	= u_cmd(4:6);

%--- run only once at the beginning
if ( size(faces_B,1)==0 ),
	%--- initial fuel
	initial_fuel	= x_(N_fuel);
	%--- get screen size
	Pix_SS = get(0,'screensize');
	%--- spacecraft main body
	Lx		= thr_arm*1.1;
	Ly		= Lx;
	Lz		= Lx;
	r		= [0;-Ly;0];
	R		= eye(3,3);
	[vertices_B, faces_B] = calcBlock(r, R, Lx, Ly, Lz);
	%--- solar sail
	Lx		= sqrt(A);
	Ly		= Lx;
	Lz		= thr_arm/10;
	r		= [0;-thr_arm*1.1/2+sqrt(2)/2*Lx;0];
	R		= [cos(pi/4),-sin(pi/4),0; sin(pi/4),cos(pi/4),0;0,0,1];
	[vertices_S, faces_S] = calcBlock(r, R, Lx, Ly, Lz);
	%--- axes of the body fixed frame 
	axes_body_L	= [0,0,0;Lx/4,0,0;0,Lx/4,0;0,0,Lx/4];
	%--- reaction wheels installed on the spacecraft main body
	Height	= thr_arm*0.1;
	Radius	= thr_arm/4;
	SideCount	= 10;
	r		= [0;-thr_arm*1.1/2-Height/2;0];
	R		= [1,0,0;0,cos(pi/2),-sin(pi/2);0, sin(pi/2),cos(pi/2)];
	[vertices_wy, faces_w] = calcCylinder(r, R, Radius, Height, SideCount);
	r		= [0;-thr_arm*1.1;-thr_arm*1.1/2+Height/2];
	R		= eye(3,3);
	[vertices_wz, faces_w] = calcCylinder(r, R, Radius, Height, SideCount);
	%--- pair of thrusters installed on the spacecraft main body
	Lx		= thr_arm*0.05;
	Ly		= Lx;
	Lz		= thr_arm*0.2;
	r		= [0;-thr_arm*1.1*1.5+Ly; thr_arm*1.1/2+Lz/2];
	R		= eye(3,3);
	[vertices_Thr.xp1, faces_Thr.xp1] = calcBlock(r, R, Lx, Ly, Lz);
	r		= [0;-thr_arm*1.1*0.5-Ly;-thr_arm*1.1/2-Lz/2];
	[vertices_Thr.xp2, faces_Thr.xp2] = calcBlock(r, R, Lx, Ly, Lz);
	r		= [0;-thr_arm*1.1*1.5+Ly;-thr_arm*1.1/2-Lz/2];
	[vertices_Thr.xm1, faces_Thr.xm1] = calcBlock(r, R, Lx, Ly, Lz);
	r		= [0;-thr_arm*1.1*0.5-Ly; thr_arm*1.1/2+Lz/2];
	[vertices_Thr.xm2, faces_Thr.xm2] = calcBlock(r, R, Lx, Ly, Lz);
	
	r		= [-thr_arm*1.1/2-Lz/2;-thr_arm*1.1*1.0; thr_arm*1.1/2-Lx];
	R		= [cos(pi/2),0, sin(pi/2);0,1,0;-sin(pi/2),0,cos(pi/2)];
	[vertices_Thr.yp1, faces_Thr.yp1] = calcBlock(r, R, Lx, Ly, Lz);
	r		= [ thr_arm*1.1/2+Lz/2;-thr_arm*1.1*1.0;-thr_arm*1.1/2+Lx];
	[vertices_Thr.yp2, faces_Thr.yp2] = calcBlock(r, R, Lx, Ly, Lz);
	r		= [ thr_arm*1.1/2+Lz/2;-thr_arm*1.1*1.0; thr_arm*1.1/2-Lx];
	[vertices_Thr.ym1, faces_Thr.ym1] = calcBlock(r, R, Lx, Ly, Lz);
	r		= [-thr_arm*1.1/2-Lz/2;-thr_arm*1.1*1.0;-thr_arm*1.1/2+Lx];
	[vertices_Thr.ym2, faces_Thr.ym2] = calcBlock(r, R, Lx, Ly, Lz);
	
	r		= [-thr_arm*1.1/2-Lz/2;-thr_arm*1.1*1.5+Ly;0];
	R		= [cos(pi/2),0, sin(pi/2);0,1,0;-sin(pi/2),0,cos(pi/2)];
	[vertices_Thr.zp1, faces_Thr.zp1] = calcBlock(r, R, Lx, Ly, Lz);
	r		= [ thr_arm*1.1/2+Lz/2;-thr_arm*1.1*0.5-Ly;0];
	[vertices_Thr.zp2, faces_Thr.zp2] = calcBlock(r, R, Lx, Ly, Lz);
	r		= [ thr_arm*1.1/2+Lz/2;-thr_arm*1.1*1.5+Ly;0];
	[vertices_Thr.zm1, faces_Thr.zm1] = calcBlock(r, R, Lx, Ly, Lz);
	r		= [-thr_arm*1.1/2-Lz/2;-thr_arm*1.1*0.5-Ly;0];
	[vertices_Thr.zm2, faces_Thr.zm2] = calcBlock(r, R, Lx, Ly, Lz);
end

%%% current attitude
C_I2B	= q2DCM(q);

% Draw patch
h_ov	= figure(100);
fc		= {'y','y','y','y','y','y'};
for j = 1:3,
	if ( th_torque(j)>0 ),
		fc{j*2-1}	= 'r';
	elseif ( th_torque(j)<0 ),
		fc{j*2  }	= 'r';
	end
end
set(h_ov,'Name','Bird''s eye view');
set(gcf,'Position', figure_pos(1,:));
clf
hold on
h_SB  = patch('Faces', faces_B      , 'Vertices', vertices_B      *C_I2B, 'FaceColor', 'y',  'FaceAlpha',0.5);
h_SS  = patch('Faces', faces_S      , 'Vertices', vertices_S      *C_I2B, 'FaceColor', 'b',  'FaceAlpha',1.0);
h_ys  = patch('Faces', faces_w.side , 'Vertices', vertices_wy     *C_I2B, 'FaceColor', 'g',  'FaceAlpha',1.0);
h_zs  = patch('Faces', faces_w.side , 'Vertices', vertices_wz     *C_I2B, 'FaceColor', 'g',  'FaceAlpha',1.0);
h_yb  = patch('Faces', faces_w.bttm , 'Vertices', vertices_wy     *C_I2B, 'FaceColor', 'g',  'FaceAlpha',1.0);
h_zb  = patch('Faces', faces_w.bttm , 'Vertices', vertices_wz     *C_I2B, 'FaceColor', 'g'  ,'FaceAlpha',1.0);
h_txp1= patch('Faces', faces_Thr.xp1, 'Vertices', vertices_Thr.xp1*C_I2B, 'FaceColor', fc{1},'FaceAlpha',1.0);
h_txp2= patch('Faces', faces_Thr.xp2, 'Vertices', vertices_Thr.xp2*C_I2B, 'FaceColor', fc{1},'FaceAlpha',1.0);
h_txm1= patch('Faces', faces_Thr.xm1, 'Vertices', vertices_Thr.xm1*C_I2B, 'FaceColor', fc{2},'FaceAlpha',1.0);
h_txm2= patch('Faces', faces_Thr.xm2, 'Vertices', vertices_Thr.xm2*C_I2B, 'FaceColor', fc{2},'FaceAlpha',1.0);
h_typ1= patch('Faces', faces_Thr.yp1, 'Vertices', vertices_Thr.yp1*C_I2B, 'FaceColor', fc{3},'FaceAlpha',1.0);
h_typ2= patch('Faces', faces_Thr.yp2, 'Vertices', vertices_Thr.yp2*C_I2B, 'FaceColor', fc{3},'FaceAlpha',1.0);
h_tym1= patch('Faces', faces_Thr.ym1, 'Vertices', vertices_Thr.ym1*C_I2B, 'FaceColor', fc{4},'FaceAlpha',1.0);
h_tym2= patch('Faces', faces_Thr.ym2, 'Vertices', vertices_Thr.ym2*C_I2B, 'FaceColor', fc{4},'FaceAlpha',1.0);
h_tzp1= patch('Faces', faces_Thr.zp1, 'Vertices', vertices_Thr.zp1*C_I2B, 'FaceColor', fc{5},'FaceAlpha',1.0);
h_tzp2= patch('Faces', faces_Thr.zp2, 'Vertices', vertices_Thr.zp2*C_I2B, 'FaceColor', fc{5},'FaceAlpha',1.0);
h_tzm1= patch('Faces', faces_Thr.zm1, 'Vertices', vertices_Thr.zm1*C_I2B, 'FaceColor', fc{6},'FaceAlpha',1.0);
h_tzm2= patch('Faces', faces_Thr.zm2, 'Vertices', vertices_Thr.zm2*C_I2B, 'FaceColor', fc{6},'FaceAlpha',1.0);
pO		= C_I2B'*axes_body_L(1,:)';
rx		= C_I2B'*axes_body_L(2,:)'-pO;
ry		= C_I2B'*axes_body_L(3,:)'-pO;
rz		= C_I2B'*axes_body_L(4,:)'-pO;
hqx	= quiver3(pO(1),pO(2),pO(3),rx(1),rx(2),rx(3),0);
hqy	= quiver3(pO(1),pO(2),pO(3),ry(1),ry(2),ry(3),0);
hqz	= quiver3(pO(1),pO(2),pO(3),rz(1),rz(2),rz(3),0);
set(hqx,'Color',[0,0,0],'LineWidth',2.0);
set(hqy,'Color',[0,0,0],'LineWidth',2.0);
set(hqz,'Color',[1,0,1],'LineWidth',2.0);
arrow_length	= max(max(axes_body_L));
hqg	= quiver3(pO(1),pO(2),pO(3),g_I(1)*arrow_length,g_I(2)*arrow_length,g_I(3)*arrow_length,0);
set(hqg,'Color',[0,1,0],'LineWidth',2.0);
xlim_	= xlim();
ylim_	= ylim();
zlim_	= zlim();
ht = text(xlim_(2),ylim_(2),zlim_(1),sprintf('Elapsed Time %6.1f s',t_));
set(ht,'HorizontalAlignment','center','VerticalAlignment','bottom','FontSize',16,'FontName','Arial');


% Axes settings
lx	= xlabel('x');
ly	= ylabel('y');
lz	= zlabel('z');
set(lx,'FontSize',18);
set(ly,'FontSize',18);
set(lz,'FontSize',18);
axis vis3d equal;
AZ	= -37.5;
EL	= 60;
view([AZ,EL]);
light('style','infinite')
light('Position',s_I')
grid on;
ax	= gca();
set(ax,'XTickLabel',[]);
set(ax,'YTickLabel',[]);
set(ax,'ZTickLabel',[]);
axis off;
%------------------------------------
h_sc	= figure(101);
set(h_sc,'Name','Score');
set(gcf,'Position',figure_pos(2,:));
clf
hold on
scores = [x_(N_pointing)/smt_ x_(N_fuel)/initial_fuel x_(N_bttry)/bttry_full];
fill(0.5+[-0.4,0.4,0.4,-0.4],[0,0,1,1]*scores(1),'r');
fill(1.5+[-0.4,0.4,0.4,-0.4],[0,0,1,1]*scores(2),'g');
fill(2.5+[-0.4,0.4,0.4,-0.4],[0,0,1,1]*scores(3),'b');

ab	= gca;
set(ab,'XTick',[0.5,1.5,2.5]);
set(ab,'XTickLabel',{});
ht	= text(0.5,0.0,'Pointing Time');
set(ht,'HorizontalAlignment','center','VerticalAlignment','top','FontSize',16,'Color',[1,0,0],'FontName','Arial');
ht	= text(1.5,0.0,'Fuel');
set(ht,'HorizontalAlignment','center','VerticalAlignment','top','FontSize',16,'Color',[0,1,0],'FontName','Arial');
ht	= text(2.5,0.0,'Battery');
set(ht,'HorizontalAlignment','center','VerticalAlignment','top','FontSize',16,'Color',[0,0,1],'FontName','Arial');
xlim([0,3]);
ylim([0,1]);
set(ab,'YTickLabel',[]);
ht	= text(0.5,1.0,sprintf('%5.1f s',x_(N_pointing)));
set(ht,'HorizontalAlignment','center','VerticalAlignment','bottom','FontSize',16,'FontName','Arial');
ht	= text(1.5,1.0,sprintf('%5.3f kg',x_(N_fuel)));
set(ht,'HorizontalAlignment','center','VerticalAlignment','bottom','FontSize',16,'FontName','Arial');
ht	= text(2.5,1.0,sprintf('%5.1f %%',x_(N_bttry)/bttry_full*100));
set(ht,'HorizontalAlignment','center','VerticalAlignment','bottom','FontSize',16,'FontName','Arial');
%------------------------------------
h_st	= figure(102);
set(h_st,'Name','States');
set(gcf,'Position', figure_pos(3,:));
clf
colnames	= {'X', 'Y', 'Z'};
rownames	= {'body rate [deg/s]','wheel mom. [Nms]','wheel torque [Nm]','thruster torque [Nm]','SRP torque [Nm]'};
data		= [omg'*180/pi;h_B';wh_torque';th_torque';cross(r_B,Fsrp_B)'];
dataS		= cell(5,3);
dataS{1,1}	= sprintf('%+6.4f',data(1,1));
dataS{4,1}	= sprintf('%+6.4f',data(4,1));
dataS{5,1}	= sprintf('%+6.4f',data(5,1));
for j = 2:3,
	dataS{1,j}	= sprintf('%+6.3f',data(1,j));
	dataS{2,j}	= sprintf('%+6.3f',data(2,j));
	dataS{3,j}	= sprintf('%+6.5f',data(3,j));
	dataS{4,j}	= sprintf('%+6.5f',data(4,j));
	dataS{5,j}	= sprintf('%+6.5f',data(5,j));
end
ts = uitable(h_st, 'Data', dataS, 'ColumnName', colnames, 'RowName', rownames, 'FontSize', 13);
set(ts,'Position',[20 20 480 200]);
axis off;
