function [] = set_Constants
% set_Constants.m
%
% Parameter Setting
%
% Revision history
% 250507 Drafted
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
global dth_ smt_ nde_ nsv_ ndisp nsave
global N_xo N_q N_omg N_h_B N_bttry N_fuel N_pointing
global N_L_I N_Fsrp_B N_u_cmd N_u_user N_pwr
global angle_tol s_I g_I g
global I_B n_B r_B hw_max_x hw_max_y hw_max_z trq_max thr_max thr_arm Isp 
global tank_full bttry_full cnv_eff Pwr_sc Pwr_whl0 Pwr_whl1 Pwr_thr0 Pwr_thr1
global d0 d S0 c A rho_s rho_d rho_a Bf figure_pos
global user
%%% Simulation environment parameters
dth_		= 0.1;			%% step width of numerical integration [s]
smt_ 		= 1200.0;		%% total simulation time [s]
nde_		= 13;			%% number of state variables
nsv_		= 31;			%% number of saved variabels
ndisp		= 40;			%% graph display frequency (if ndisp=2, then once in two intervals)
nsave		= 1;			%% save variable frequency (if nsave=2, then once in two intervals)
figure_pos	= [[9 51 961 729];[971 435 560 344];[974 33 560 284]];
%%% Simulation setting
goal_angle	= pi/6;		%% goal angle [rad]
%% temporary
angle_tol	= 3.0*pi/180;	%% goal angle tolerance [rad]#
s_I			= [0;0;1];		%% sun direction vector in inertial frame
g_I			= [sin(goal_angle);0;cos(goal_angle)];	%% goal direction vector in intertial frame#
g			= 9.80665;		%% standard gravity of the earth [m/s2]

%%% s/c property
I_B			= diag([109;6.90;116]);	%% moment of inertia, [kgm2]
n_B			= [0;0;1];		%% normal vector of the solar sail surface in body fixed frame [-]
r_B			= [0.030;5.170;-0.050];	%% the vector from center of mass to the center of SRP in body fixed frame [m]
hw_max_x	= 0;			%% maximum momentum storable in the x-axis wheel [Nms]
hw_max_y	= 1;			%% maximum momentum storable in the y-axis wheel [Nms]
hw_max_z	= 0.1;			%% maximum momentum storable in the z-axis wheel [Nms]
trq_max		= 0.01;			%% maximum allowable wheel torque [Nm]
thr_max		= 0.4;			%% maximum thruster force [N]
thr_arm		= 0.5;			%% thruster arm length (distance of the thruster pair) [m]
Isp			= 40;			%% specific impulse [s]
tank_full 	= 1.0;			%% tank full level [kg]#
bttry_full	= 45000;		%% battery full level [Ws]#
cnv_eff		= 0.20;			%% conversion efficiency (considering pasting area) [-]
Pwr_sc		= 25;			%% consumed power by the s/c (stationary)
Pwr_whl0	= 5;			%% consumed power by one wheel (stand by) [W]
Pwr_whl1	= 640;			%% consumed power by one wheel (actuated) [W/Nm]
Pwr_thr0	= 3;			%% consumed power by a pair of thrusters (stand by) [W]
Pwr_thr1	= 15/(0.4*0.5);	%% consumed power by a pair of thrusters (actuated) [W/Nm]

%%% solar radiation pressure related parameters
d0			= 1;		%% mean distance between the sun and the earth
d			= 1;		%% current distance between the sun and the spacecraft
S0			= 1366;		%% Power input from the sun [W/m2]=[J/m2s]=[kg/s3]
c			= 3.0e8;	%% speed of light [m/s]
A			= 9*9;		%% area of the plane [m2]
rho_s		= 0.882;	%% the specular constant
rho_d		= 0.065;	%% the diffusion constant
rho_a		= 0.053;	%% the absorption constant
Bf			= (2/3);	%% Lambertian constant
rho_a	= sqrt(1-rho_s*rho_s-rho_d*rho_d);

%%% Note. The value that has sharp(#) may be changed at the contest site to excite the game.

%%% constant to be transfered to the user via global varialbe "user"
%%% environment property
user.angle_tol	= angle_tol;
user.s_I	= s_I;
user.g_I	= g_I;
user.g		= g;

%%% s/c property
user.I_B	= I_B;
user.n_B	= n_B;
user.r_B	= r_B;
user.hw_max_x	= hw_max_x;
user.hw_max_y	= hw_max_y;
user.hw_max_z	= hw_max_z;
user.trq_max	= trq_max;
user.thr_max	= thr_max;
user.thr_arm	= thr_arm;
user.Isp		= Isp;
user.bttry_full	= bttry_full;
user.cnv_eff	= cnv_eff;
user.Pwr_sc		= Pwr_sc;
user.Pwr_whl0	= Pwr_whl0;
user.Pwr_whl1	= Pwr_whl1;
user.Pwr_thr0	= Pwr_thr0;
user.Pwr_thr1	= Pwr_thr1;

%%% s/c property
user.d0		= d0;
user.d		= d;
user.S0		= S0;
user.c		= c;
user.A		= A;
user.rho_s	= rho_s;
user.rho_d	= rho_d;
user.rho_a	= rho_a;
user.Bf		= Bf;

%%% index to the saved variables
N_q			=  1: 4;	%% quaternion of the s/c (4x1)
N_omg		=  5: 7;	%% body rate of the s/c (3x1)
N_h_B		=  8:10;	%% momentum stored in each wheel (3x1)
N_bttry		= 11;		%% battery level (1x1)
N_fuel		= 12;		%% remaining fuel (1x1)
N_pointing	= 13;		%% accumulated pointing time (1x1)
N_L_I		= 14:16;	%% total angular momentum in the inertial frame (3x1)
N_Fsrp_B	= 17:19;	%% solar radiation pressure in the body frame (3x1)
N_xo		=  1:nde_;	%% state variable (nde_x1)
N_u_cmd		= 20:25;	%% realized torques in the dynamics (6x1)
N_u_user	= 26:30;	%% thruster torque and wheel torque commanded by the user (5x1)
N_pwr		= 31;		%% consumed power (1x1)
%%%
%%%
