function [ts,xs] = set_InitialValues(ts,xs)
% set_InitialValues.m
%
% Set Initial Values
%
% Revision history
% 250507 Drafted
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
global x_ dx_ t_ nde_ nsv_ smt_
global N_xo N_q N_omg N_h_B N_bttry N_fuel N_pointing
global tank_full bttry_full hw_max_x hw_max_y hw_max_z
global user_message

%
addpath('util');
addpath('user');
%
x_		= zeros(nsv_,1);	% state variables and saved variabels
dx_		= zeros(nde_,1);	% 1st time derivative of state variables
t_		= 0;				% time [s]
%
%
%%% s/c property
%%% set initial attitude and body rate
alpha		= 0;
beta		= 0;
C_O2R		= [[cos(alpha),0,-sin(alpha)];...
			   [sin(alpha)*sin(beta), cos(beta),cos(alpha)*sin(beta)];...
			   [sin(alpha)*cos(beta),-sin(beta),cos(alpha)*cos(beta)]];
q			= DCM2q(C_O2R');
if ( q(4)<0 ),
	q		= -q;
end
omg			= zeros(3,1);
h_B			= [0;0;0];	%% wheel momentum in body fixed frame [Nms]
h_B(1)		= min(h_B(1)*sign(h_B(1)),hw_max_x)*sign(h_B(1));
h_B(2)		= min(h_B(2)*sign(h_B(2)),hw_max_y)*sign(h_B(2));
h_B(3)		= min(h_B(3)*sign(h_B(3)),hw_max_z)*sign(h_B(3));

x_(N_q)	 	= q;			%% initial quaternion of the s/c [-]#
x_(N_omg)	= omg;			%% initial body rate of the s/c [rad/s]
x_(N_h_B)	= h_B;			%% initial stored momentum of each wheel [Nms]
x_(N_bttry)	= bttry_full;	%% initial battery level [Ah]#
x_(N_fuel)	= tank_full ;	%% initial fuel amount [kg]#
x_(N_pointing)	= 0;		%% initial accumulated pointing time [s]

%%% Note. The value that has sharp(#) may be changed at the contest site to excite the game.

%%% save initial values
ts = t_;
xs = x_;

%%% initialize user message
user_message	= 'User message';
exe_RefreshScreen;
drawnow;
