function q = DCM2q(C)
%% Input
%% C: a direction cosine matrix (DCM) (3x3)
%% Output
%% q: quaternion (4x1 vector)
%%
%% we choose q4 positive
q4		= sqrt(C(1,1)+C(2,2)+C(3,3)+1.0)/2.0;
if ( q4>1e-8 ),
	q1q4	= (C(2,3) - C(3,2))/4.0;
	q1		= q1q4/q4;
	q2q4	= (C(3,1) - C(1,3))/4.0;
	q2		= q2q4/q4;
	q3q4	= (C(1,2) - C(2,1))/4.0;
	q3		= q3q4/q4;
else
	q1		= sqrt(C(1,1)-C(2,2)-C(3,3)+1.0)/2.0;
	q1q4	= (C(2,3) - C(3,2))/4.0;
	%% chose sign of q1 such that q4 is positive
	if ( q1q4 < 0 ),
		q1		= -q1;
	end
	q4		= q1q4/q1;
	q1q2	= (C(1,2)+C(2,1))/4.0;
	q2		= q1q2/q1;
	q1q3	= (C(1,3)+C(3,1))/4.0;
	q3		= q1q3/q1;
end
q		= [q1;q2;q3;q4];
